@@ -64,13 +64,14 @@ TEST_NEW (view_implements_ggv_document)
 	char **page_names;
 	char **p;
 
-	view = GPDF_VIEW (gpdf_view_new (NULL));
+	view = GPDF_VIEW (g_object_new (GPDF_TYPE_VIEW,
+					"aa", TRUE,	/* FIXME: a pref ? */
+					"pdf_doc", simple_links_doc, 
+					NULL));
 	TEST (view != NULL);
 	TEST (GPDF_IS_VIEW (view));
 	TEST (GGV_IS_DOCUMENT (view));
 
-	gpdf_view_set_pdf_doc (view, simple_links_doc);
-
 	TEST (2 == ggv_document_get_page_count (GGV_DOCUMENT (view)));
 
 	page_names = ggv_document_get_page_names (GGV_DOCUMENT (view));
